@@ -4,13 +4,13 @@ from .world import world
 class Entity():
     '''Base entity class'''
 
-    __slots__ = ['type', 'id', 'components', 'initialized']
+    __slots__ = ['type', 'id', 'components', 'initialized', 'default_components']
 
     default_components = {}
 
 
-    def __init__(self, type=None, **default_components):
-        self.type = type or type(self).__name__
+    def __init__(self, ent_type=None, **default_components):
+        self.type = ent_type or type(self).__name__
         self.id = None
         self.initialized = False
         self.components = {}
